==> kpprinter-0.0.3.tar.gz: android/src/main/java/com/example/kpprinter/java/MTPPrintsSdk.java <==
package com.example.kpprinter.java;

import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.util.Log;

import com.lvrenyang.io.Pos;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

public class MTPPrintsSdk {

    public static boolean PrintTicket(Pos pos,
                                      List<Map<String,String>> printMsg,
                                      String titleName,
                                      int nCount,
                                      int nPrintContent,
                                      boolean bCheckReturn) {

        boolean bPrintResult = false;

        byte[] status = new byte[1];
        if (!bCheckReturn || (bCheckReturn && pos.POS_QueryStatus(status, 3000, 2))) {
            for (int i = 0; i < nCount; ++i) {
                if (!pos.GetIO().IsOpened())
                    break;

                if (nPrintContent >= 1) {

                    for (int j = 0;j<printMsg.size();j++){
                        String layoutStyle = printMsg.get(j).get("LayoutStyle");
                        String content = printMsg.get(j).get("content");
                        Log.e("myContent==",content+"");
                        switch (layoutStyle){
                            case "left":
                                pos.POS_S_Align(0);
                                pos.POS_TextOut(content+"",0, 0, 0, 0, 0,0);
                                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);

                                break;
                            case"center":
                                pos.POS_S_Align(1);
                                pos.POS_TextOut("打印第2行",0, 0, 0, 0, 0, 0);
                                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);

                                break;
                            case "right":
                                pos.POS_S_Align(2);
                                pos.POS_TextOut(content,0, 0, 0, 0, 0, 0);
                                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);

                                break;
                            case "enter":
                                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);
                                break;
                        }
                    }

//                    pos.POS_S_TextOut("REC" + String.format("%03d", i) + "\r\nPrinter\r\n测试页\r\n\r\n", 0, 1, 1, 0, 0x100);
//                    pos.POS_S_TextOut("扫二维码下载苹果APP\r\n", 0, 0, 0, 0, 0x100);
//                    pos.POS_TextOut("鳥インフル\r\n", 4, 0, 0, 0, 0, 0);
//                    pos.POS_S_SetQRcode("https://appsto.re/cn/2KF_bb.i", 8, 0, 3);
                    pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);
                    pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);
                    pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);

                }

            }

            if (bCheckReturn) {
                bPrintResult = pos.POS_TicketSucceed(0, 30000);
            } else {
                bPrintResult = pos.GetIO().IsOpened();
            }
        }

        return bPrintResult;
    }

    /**
     * 从Assets中读取图片
     */
    public static Bitmap getImageFromAssetsFile(Context ctx, String fileName) {
        Bitmap image = null;
        AssetManager am = ctx.getResources().getAssets();
        try {
            InputStream is = am.open(fileName);
            image = BitmapFactory.decodeStream(is);
            is.close();
        } catch (IOException e) {
            e.printStackTrace();
        }

        return image;
    }

    public static Bitmap resizeImage(Bitmap bitmap, int w, int h) {
        // load the origial Bitmap
        Bitmap BitmapOrg = bitmap;

        int width = BitmapOrg.getWidth();
        int height = BitmapOrg.getHeight();
        int newWidth = w;
        int newHeight = h;

        // calculate the scale
        float scaleWidth = ((float) newWidth) / width;
        float scaleHeight = ((float) newHeight) / height;

        // create a matrix for the manipulation
        Matrix matrix = new Matrix();
        // resize the Bitmap
        matrix.postScale(scaleWidth, scaleHeight);
        // if you want to rotate the Bitmap
        // matrix.postRotate(45);

        // recreate the new Bitmap
        Bitmap resizedBitmap = Bitmap.createBitmap(BitmapOrg, 0, 0, width,
                height, matrix, true);

        // make a Drawable from Bitmap to allow to set the Bitmap
        // to the ImageView, ImageButton or what ever
        return resizedBitmap;
    }

    public static Bitmap getTestImage1(int width, int height) {
        Bitmap bitmap = Bitmap.createBitmap(width, height, Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        Paint paint = new Paint();

        paint.setColor(Color.WHITE);
        canvas.drawRect(0, 0, width, height, paint);

        paint.setColor(Color.BLACK);
        for (int i = 0; i < 8; ++i) {
            for (int x = i; x < width; x += 8) {
                for (int y = i; y < height; y += 8) {
                    canvas.drawPoint(x, y, paint);
                }
            }
        }
        return bitmap;
    }


    public static Bitmap getTestImage2(int width, int height) {
        Bitmap bitmap = Bitmap.createBitmap(width, height, Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        Paint paint = new Paint();

        paint.setColor(Color.WHITE);
        canvas.drawRect(0, 0, width, height, paint);

        paint.setColor(Color.BLACK);
        for (int y = 0; y < height; y += 4) {
            for (int x = y % 32; x < width; x += 32) {
                canvas.drawRect(x, y, x + 4, y + 4, paint);
            }
        }
        return bitmap;
    }
}

==> kpprinter-0.0.17.tar.gz: android/src/main/java/com/example/kpprinter/java/MTPPrintsSdk.java <==
package com.example.kpprinter.java;

import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.util.Log;

import com.lvrenyang.io.Pos;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

public class MTPPrintsSdk {

    public static boolean PrintTicket(Context ctx,Pos pos,
                                      List<Map<String,String>> printMsg,
                                      int nCount,
                                      boolean bCheckReturn) {
        boolean bPrintResult = false;

        byte[] status = new byte[1];
        if (!bCheckReturn || (bCheckReturn && pos.POS_QueryStatus(status, 3000, 2))) {
            for (int i = 0; i < nCount; ++i) {
                if (!pos.GetIO().IsOpened())
                    break;
                Bitmap printLine = getImageFromAssetsFile(ctx, "print_line.png");
//                if (nPrintContent >= 1) {

                for (int j = 0;j<printMsg.size();j++){
                    String layoutStyle = printMsg.get(j).get("LayoutStyle");
                    String content = printMsg.get(j).get("content");
                    Log.e("myContent==",content+"");
                    switch (layoutStyle){
                        case "left":
                            pos.POS_S_Align(0);
                            pos.POS_TextOut(content+"\n",0, 0, 0, 0, 0,0);
                            break;
                        case"center":
                            pos.POS_S_Align(1);
                            pos.POS_TextOut(content+"\n",0, 0, 0, 0, 0, 0);

                            break;
                        case "right":
                            pos.POS_S_Align(2);
                            pos.POS_TextOut(content+"\n",0, 0, 0, 0, 0, 0);

                            break;
                        case "enter":
                            pos.POS_TextOut("\n", 0, 0, 0, 0, 0,0);
                            break;
                        case "signlineSeperate":
                            if (printLine!=null)
                                pos.POS_PrintPicture(printLine, 384, 1, 0);
                            break;
                    }
                }
//                    pos.POS_S_TextOut("扫二维码下载苹果APP\n", 0, 0, 0, 0, 0x100);
//                    pos.POS_TextOut("鳥インフル", 4, 0, 0, 0, 0, 0);
//                    pos.POS_S_SetQRcode("https://appsto.re/cn/2KF_bb.i", 8, 0, 3);
                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);
                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);
                pos.POS_S_TextOut("\n", 0, 0, 0, 0x00, 0x00);

            }

        }

        if (bCheckReturn) {
            bPrintResult = pos.POS_TicketSucceed(0, 30000);
        } else {
            bPrintResult = pos.GetIO().IsOpened();
        }
//        }

        return bPrintResult;
    }

    /**
     * 从Assets中读取图片
     */
    public static Bitmap getImageFromAssetsFile(Context ctx, String fileName) {
        Bitmap image = null;
        AssetManager am = ctx.getResources().getAssets();
        try {
            InputStream is = am.open(fileName);
            image = BitmapFactory.decodeStream(is);
            is.close();
        } catch (IOException e) {
            e.printStackTrace();
        }

        return image;
    }

    public static Bitmap resizeImage(Bitmap bitmap, int w, int h) {
        // load the origial Bitmap
        Bitmap BitmapOrg = bitmap;

        int width = BitmapOrg.getWidth();
        int height = BitmapOrg.getHeight();
        int newWidth = w;
        int newHeight = h;

        // calculate the scale
        float scaleWidth = ((float) newWidth) / width;
        float scaleHeight = ((float) newHeight) / height;

        // create a matrix for the manipulation
        Matrix matrix = new Matrix();
        // resize the Bitmap
        matrix.postScale(scaleWidth, scaleHeight);
        // if you want to rotate the Bitmap
        // matrix.postRotate(45);

        // recreate the new Bitmap
        Bitmap resizedBitmap = Bitmap.createBitmap(BitmapOrg, 0, 0, width,
                height, matrix, true);

        // make a Drawable from Bitmap to allow to set the Bitmap
        // to the ImageView, ImageButton or what ever
        return resizedBitmap;
    }

    public static Bitmap getTestImage1(int width, int height) {
        Bitmap bitmap = Bitmap.createBitmap(width, height, Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        Paint paint = new Paint();

        paint.setColor(Color.WHITE);
        canvas.drawRect(0, 0, width, height, paint);

        paint.setColor(Color.BLACK);
        for (int i = 0; i < 8; ++i) {
            for (int x = i; x < width; x += 8) {
                for (int y = i; y < height; y += 8) {
                    canvas.drawPoint(x, y, paint);
                }
            }
        }
        return bitmap;
    }


    public static Bitmap getTestImage2(int width, int height) {
        Bitmap bitmap = Bitmap.createBitmap(width, height, Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        Paint paint = new Paint();

        paint.setColor(Color.WHITE);
        canvas.drawRect(0, 0, width, height, paint);

        paint.setColor(Color.BLACK);
        for (int y = 0; y < height; y += 4) {
            for (int x = y % 32; x < width; x += 32) {
                canvas.drawRect(x, y, x + 4, y + 4, paint);
            }
        }
        return bitmap;
    }
}
